@@ -379,9 +379,13 @@ class Iterator(object):
 
         self.ncrashes = 0
         self.niters = 0
-        logger.info("Iterating....")
-        logger.info(print_control(self.control, "Current control: "))
-        logger.info(print_control(self.target, "Target: "))
+        #print(type(self.control))
+        control_name = self.control[0].name()
+        logger.info(f"Iterating to target control ({control_name})...")
+        msg = f"Current control: {control_name} = "
+        logger.info(print_control(self.control, msg))
+        msg = "Target: "
+        logger.info(print_control(self.target, msg))
         while not self.target_reached():
 
             self.niters += 1
